@@ -13,7 +13,7 @@
 #' @return Axed recipe object.
 #'
 #' @examples
-#' suppressWarnings(suppressMessages(library(recipes)))
+#' suppressPackageStartupMessages(library(recipes))
 #' library(modeldata)
 #'
 #' data(biomass)
@@ -33,15 +33,19 @@
 #'   return(
 #'     recipe(mpg ~ cyl, data = mtcars) %>%
 #'       step_center(all_predictors()) %>%
-#'       step_scale(all_predictors())
+#'       step_scale(all_predictors()) %>%
+#'       prep()
 #'   )
 #' }
 #'
-#' # Remove junk
-#' cleaned_recipes <- axe_env(wrapped_recipes(), verbose = TRUE)
+#' # Remove junk in environment
+#' cleaned1 <- axe_env(wrapped_recipes(), verbose = TRUE)
+#' # Replace prepared training data with zero-row slice
+#' cleaned2 <- axe_fitted(wrapped_recipes(), verbose = TRUE)
 #'
 #' # Check size
-#' lobstr::obj_size(cleaned_recipes)
+#' lobstr::obj_size(cleaned1)
+#' lobstr::obj_size(cleaned2)
 #'
 #' @name axe-recipe
 NULL
@@ -180,3 +184,18 @@ axe_env.quosure <- function(x, ...) {
   attr(x, ".Environment") <- rlang::base_env()
   x
 }
+
+#' Remove fitted values
+#'
+#' @rdname axe-recipe
+#' @export
+axe_fitted.recipe <- function(x, verbose = FALSE, ...) {
+  old <- x
+  x$template <- vctrs::vec_ptype(x$template)
+
+  add_butcher_attributes(
+    x,
+    old,
+    verbose = verbose
+  )
+}
